@@ -3,6 +3,16 @@ import os
 from pathlib import Path
 
 
+def pytest_addoption(parser):
+    parser.addoption("--rabbitmq", action="store_true",
+                     help="run the tests only in case of rabbitmq server active")
+
+
+def pytest_runtest_setup(item):
+    if 'rabbitmq' in item.keywords and not item.config.getoption("--rabbitmq"):
+        pytest.skip("need --rabbitmq for full testing with rabbitmq server")
+
+
 @pytest.fixture(scope='session')
 def data_folder():
     dirname = os.path.dirname(__file__)
